Stan Math Library: stan::math::promote_scalar_type< T, Eigen::Matrix< S, Eigen::Dynamic, 1 > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::promote_scalar_type< T, Eigen::Matrix< S, Eigen::Dynamic, 1 > > Struct Template Reference

Template metaprogram to calculate a type for a vector whose underlying scalar is converted from the second template parameter type to the first. More...

`#include <promote_scalar_type.hpp>`

## Public Types
typedef Eigen::Matrix< typename promote_scalar_type< T, S >::type, Eigen::Dynamic, 1 > | type
| The promoted type. More...

## Detailed Description

### template<typename T, typename S>
struct stan::math::promote_scalar_type< T, Eigen::Matrix< S, Eigen::Dynamic, 1 > >

Template metaprogram to calculate a type for a vector whose underlying scalar is converted from the second template parameter type to the first.

Template Parameters

  T | result scalar type.
  S | input vector scalar type

Definition at line 43 of file promote_scalar_type.hpp.

## Member Typedef Documentation

template<typename T , typename S >

typedef Eigen::Matrix<typename promote_scalar_type<T, S>::type, Eigen::Dynamic, 1> stan::math::promote_scalar_type< T, Eigen::Matrix< S, Eigen::Dynamic, 1 > >::type

The promoted type.

Definition at line 49 of file promote_scalar_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/fun/promote_scalar_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.